pub struct SkuPrepInstructions {
    pub seller_sku: Option<String>,
    pub ASIN: Option<String>,
    pub barcode_instruction: Option<BarcodeInstruction>,
    pub prep_guidance: Option<PrepGuidance>,
    pub prep_instruction_list: Option<Vec<PrepInstruction>>,
    pub amazon_prep_fees_details_list: Option<Vec<AmazonPrepFeesDetails>>,
}
SkuPrepInstructions : Labeling requirements and item preparation instructions to help you prepare items for shipment to Amazon’s fulfillment network.

Fields

seller_sku: Option<String>

The seller SKU of the item.

ASIN: Option<String>

The Amazon Standard Identification Number (ASIN) of the item.

barcode_instruction: Option<BarcodeInstruction>prep_guidance: Option<PrepGuidance>prep_instruction_list: Option<Vec<PrepInstruction>>

A list of preparation instructions to help with item sourcing decisions.

amazon_prep_fees_details_list: Option<Vec<AmazonPrepFeesDetails>>

A list of preparation instructions and fees for Amazon to prep goods for shipment.

Implementations

Labeling requirements and item preparation instructions to help you prepare items for shipment to Amazon’s fulfillment network.